@@ -34,8 +34,12 @@
 #include <libosso.h>
 #endif
 
-#ifdef HAVE_HILDON_FM
+#ifdef HAVE_HILDON_FM2
+#include <hildon/hildon-file-chooser-dialog.h>
+#elif defined HAVE_HILDON_FM
 #include <hildon-widgets/hildon-file-chooser-dialog.h>
+#else
+#include <gtk/gtkfilechooserdialog.h>
 #endif
 
 #ifdef HAVE_LIBHILDON
@@ -51,7 +55,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include <gtk/gtkfilechooserdialog.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkliststore.h>
@@ -462,7 +465,7 @@ hd_home_background_dialog_file_select (HDHomeBackgroundDialog *dialog)
 
   priv = HD_HOME_BACKGROUND_DIALOG_GET_PRIVATE (dialog);
 
-#ifdef HAVE_HILDON_FM  
+#if defined HAVE_HILDON_FM  || defined HAVE_HILDON_FM2
   fdialog = hildon_file_chooser_dialog_new_with_properties (
 					  GTK_WINDOW (dialog),
 					  HILDON_HOME_FILE_CHOOSER_ACTION_PROP,
