@@ -84,9 +84,6 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 
-/* log include */
-#include <log-functions.h>
-
 /* Menu item strings */
 #define AS_HOME_ITEM 		_("tana_fi_home")
 #define AS_HOME_ITEM_ICON 	"qgn_list_home"
@@ -345,7 +342,7 @@ hn_app_switcher_get_icon_from_theme (HNAppSwitcher *app_switcher,
 				     &error);
   if (error)
   {
-    osso_log (LOG_ERR, "Could not load icon '%s': %s\n",
+    g_warning ("Could not load icon '%s': %s\n",
      	      icon_name,
 	      error->message);
 
@@ -1131,7 +1128,7 @@ hn_app_switcher_osso_initialize (HNAppSwitcher *app_switcher)
 
   if (!priv->osso)
   {
-    osso_log(LOG_ERR, "Failed to initialize libOSSO");
+    g_warning("Failed to initialize libOSSO");
       
     return;
   }
